<?php
namespace Ekliptor\Wordpress;


use Ekliptor\CashP\BlockchainApi\Structs\SlpToken;


class PreInstalledTokens {
	/** @var array */
	protected static $tokens = null;
	
	
	private function __construct() {
	}
	
	/**
	 * Get an associative array of pre-installed tokens with the token-symbol as key.
	 * @return array
	 */
	public static function getTokens(): array {
		if (static::$tokens !== null)
			return static::$tokens;
		$usdh = new SlpToken(); // https://simpleledger.info/#token/c4b0d62156b3fa5c8f3436079b5394f7edc1bef5dc1cd2f9d0c4d46f82cca479
		$usdh->id = 'c4b0d62156b3fa5c8f3436079b5394f7edc1bef5dc1cd2f9d0c4d46f82cca479';
		$usdh->name = 'HonestCoin';
		$usdh->symbol = 'USDH';
		$usdh->documentUri = 'http://www.honestcoin.io/';
		$usdh->icon = 'https://www.honestcoin.io/img/logo.png';
		$usdh->rate = 1.0;
		$usdh->decimals = 2;
		$usdh->enabled = true;
		/*
		$spice = new SlpToken(); // https://simpleledger.info/#token/4de69e374a8ed21cbddd47f2338cc0f479dc58daa2bbe11cd604ca488eca0ddf
		$spice->id = '4de69e374a8ed21cbddd47f2338cc0f479dc58daa2bbe11cd604ca488eca0ddf';
		$spice->name = 'SPICE';
		$spice->symbol = 'SPICE';
		$spice->documentUri = 'https://spicetoken.org/'; // official value: spiceslp@gmail.com
		//$spice->icon = 'https://spicetoken.org/img/placeholders/spice_1_680_600.svg'; // white BG
		//$spice->icon = 'https://tokens.bch.sx/248/4de69e374a8ed21cbddd47f2338cc0f479dc58daa2bbe11cd604ca488eca0ddf.png'; // host it locally
		$spice->icon = plugins_url( 'img/spice.png', BCHSLP_PAYMENTS__PLUGIN_DIR . 'slp-payments.php' );
		$spice->rate = 0.001; // TODO rate is not constant? get it from an API
		$spice->decimals = 8;
		$spice->enabled = true;
		*/
		static::$tokens = array(
				'USDH' => $usdh,
				//'SPICE' => $spice,
		);
		return static::$tokens;
	}
	
	/**
	 * Returns all pre-installed tokens as associative array.
	 * @return array
	 */
	public static function getSettingsArray(): array {
		$tokens = static::getTokens();
		$wcTokens = array();
		foreach ($tokens as $symbol => $token) {
			$wcTokens[$symbol] = (array)$token;
		}
		return $wcTokens;
	}
	
	/**
	 * Returns all pre-installed tokens as associative array with the properties named as our Woocommerce settings.
	 * @return array
	 */
	public static function getWoocommerceSettingsArray(): array {
		$tokens = static::getTokens();
		$wcTokens = array();
		foreach ($tokens as $symbol => $preToken) {
			$settings = array();
			$settings['tokenID'] = $preToken->id;
			$settings['tokenName'] = $preToken->name;
			$settings['tokenTickerSymbol'] = $preToken->symbol;
			$settings['tokenWebsite'] = $preToken->documentUri;
			$settings['tokenImage'] = $preToken->icon;
			$settings['tokenRateUSD'] = $preToken->rate;
			$settings['enableCurrentToken'] = $preToken->enabled ? 'yes' : 'no';
			$wcTokens[$symbol] = $settings;
		}
		return $wcTokens;
	}
}
?>